
function OnFinish(selProj, selObj)
{
	try
	{
		var strProjectPath = wizard.FindSymbol('PROJECT_PATH');
		var strProjectName = wizard.FindSymbol('PROJECT_NAME');

		selProj = CreateCustomProject(strProjectName, strProjectPath);
		AddConfig(selProj, strProjectName);
		AddFilters(selProj);

		var InfFile = CreateCustomInfFile();
		AddFilesToCustomProj(selProj, strProjectName, strProjectPath, InfFile);
		PchSettings(selProj);
		InfFile.Delete();


		selProj.Object.Save();
	}
	catch(e)
	{
		wizard.ReportError("Err source: OnFinish");
		if (e.description.length != 0) {
			wizard.SetErrorInfo(e.description, e.number);
		}
		
		wizard.ReportError();
			
		return e.number
	}
}


function CreateCustomProject(strProjectName, strProjectPath)
{
	try
	{
		var strProjTemplatePath = wizard.FindSymbol('PROJECT_TEMPLATE_PATH');
		var strProjTemplate = '';
		strProjTemplate = strProjTemplatePath + '\\default.vcproj';

		var Solution = dte.Solution;
		var strSolutionName = "";
		if (wizard.FindSymbol("CLOSE_SOLUTION"))
		{
			Solution.Close();
			strSolutionName = wizard.FindSymbol("VS_SOLUTION_NAME");
			if (strSolutionName.length)
			{
				var strSolutionPath = strProjectPath.substr(0, strProjectPath.length - strProjectName.length);
				Solution.Create(strSolutionPath, strSolutionName);
			}
		}

		var strProjectNameWithExt = '';
		strProjectNameWithExt = strProjectName + '.vcproj';

		var oTarget = wizard.FindSymbol("TARGET");
		var prj;
		if (wizard.FindSymbol("WIZARD_TYPE") == vsWizardAddSubProject)  // vsWizardAddSubProject
		{
			var prjItem = oTarget.AddFromTemplate(strProjTemplate, strProjectNameWithExt);
			prj = prjItem.SubProject;
		}
		else
		{
			prj = oTarget.AddFromTemplate(strProjTemplate, strProjectPath, strProjectNameWithExt);
		}
		return prj;
	}
	catch(e)
	{
		wizard.ReportError("Err source: CreateCustomProject");
		throw e;
	}
}

function AddFilters(proj)
{
	try
	{
		// Add the folders to your project
		var strSrcFilter = wizard.FindSymbol('SOURCE_FILTER');
		var group = proj.Object.AddFilter('Source Files');
		group.Filter = strSrcFilter;

		var strSrcFilter = wizard.FindSymbol('HEADER_FILTER');
		var group = proj.Object.AddFilter('Header Files');
		group.Filter = strSrcFilter;

	}
	catch(e)
	{
		wizard.ReportError("Err source: AddFilters");
		throw e;
	}
}

function AddConfig(proj, strProjectName)
{
	try
	{
		
		/*********************************************************************/
		// SETTINGS FOR DEBUG VERSION
		
		var config = proj.Object.Configurations("Debug|Win32");
		config.CharacterSet = charSetMBCS;
		
		
		// Compiler's Settings!!!!

		var CLTool = config.Tools("VCCLCompilerTool");

		// Warning CLTool.RuntimeLibrary = runtimeLibraryOption.rtSingleThreadedDebug
		// not work with Visual C++ 8 Express
		// Bug corrected with try catch
		try{ CLTool.RuntimeLibrary = runtimeLibraryOption.rtSingleThreadedDebug;}catch(ex) 	{}
		
		CLTool.Optimization = optimizeOption.optimizeDisabled;
		CLTool.DebugInformationFormat = debugOption.debugEditAndContinue;
		CLTool.WarningLevel = warningLevelOption.warningLevel_3;

		var strDefines = "WIN32;_DEBUG";

		strDefines += ";_CONSOLE";

		CLTool.PreprocessorDefinitions = strDefines;

		CLTool.UsePrecompiledHeader = pchNone;
		
		// Added by Federico Chesani - 03/08/2006
		CLTool.CompileAs = CompileAsOptions.compileAsC; // force compiling the project as a C project (option /TC)
		CLTool.DisableSpecificWarnings = "4996"; // Disable the warning for new (secure) definitions of scanf-like functions

		
		
		
		/*********************************************************************/
		// Linker's Settings
		
		var LinkTool = config.Tools("VCLinkerTool");
		LinkTool.ProgramDatabaseFile = "$(outdir)/" + strProjectName + ".pdb";
		LinkTool.GenerateDebugInformation = true;
		LinkTool.LinkIncremental = linkIncrementalYes;
		LinkTool.SubSystem = subSystemConsole;
		LinkTool.OutputFile = "$(outdir)/" + strProjectName + ".exe";





		
		/*********************************************************************/
		// SETTINGS FOR RELEASE VERSION
		
		config = proj.Object.Configurations.Item("Release|Win32");
		config.CharacterSet = charSetMBCS;


		// Compiler's Settings!!!!

		var CLTool = config.Tools("VCCLCompilerTool");

		CLTool.UsePrecompiledHeader = pchNone;

		CLTool.WarningLevel = warningLevelOption.warningLevel_3;
		
		// Warning CLTool.RuntimeLibrary = runtimeLibraryOption.rtSingleThreaded
		// not work with Visual C++ 8 Express
		// Bug corrected with try catch
		
		try{ CLTool.RuntimeLibrary = runtimeLibraryOption.rtSingleThreaded;}catch (ex)	{}
		

		CLTool.InlineFunctionExpansion = expandOnlyInline;

		var strDefines = "WIN32;NDEBUG;_MBCS";

		strDefines += ";_CONSOLE";

		CLTool.PreprocessorDefinitions = strDefines;
		
		// Added by Federico Chesani - 03/08/2006
		CLTool.CompileAs = CompileAsOptions.compileAsC; // force compiling the project as a C project (option /TC)
		CLTool.DisableSpecificWarnings = "4996"; // Disable the warning for new (secure) definitions of scanf-like functions



		// Linker's Settings
		
		var LinkTool = config.Tools("VCLinkerTool");
		LinkTool.GenerateDebugInformation = true;
		LinkTool.LinkIncremental = linkIncrementalNo;

		LinkTool.SubSystem = subSystemConsole;

		LinkTool.OutputFile = "$(outdir)/" + strProjectName + ".exe";	
	}
	catch(e)
	{
		wizard.ReportError("Err source: AddConfig");
		throw e;
	}
}


function PchSettings(proj)
{
	// TODO: specify pch settings
}

function DelFile(fso, strWizTempFile)
{
	try
	{
		if (fso.FileExists(strWizTempFile))
		{
			var tmpFile = fso.GetFile(strWizTempFile);
			tmpFile.Delete();
		}
	}
	catch(e)
	{
		wizard.ReportError("Err source: DelFile");
		throw e;
	}
}

function CreateCustomInfFile()
{
	try
	{
		var fso, TemplatesFolder, TemplateFiles, strTemplate;
		fso = new ActiveXObject('Scripting.FileSystemObject');

		var TemporaryFolder = 2;
		var tfolder = fso.GetSpecialFolder(TemporaryFolder);
		var strTempFolder = tfolder.Drive + '\\' + tfolder.Name;

		var strWizTempFile = strTempFolder + "\\" + fso.GetTempName();

		var strTemplatePath = wizard.FindSymbol('TEMPLATES_PATH');
		var strInfFile = strTemplatePath + '\\Templates.inf';
		wizard.RenderTemplate(strInfFile, strWizTempFile);

		var WizTempFile = fso.GetFile(strWizTempFile);
		return WizTempFile;
	}
	catch(e)
	{
		wizard.ReportError("Err source: CreateCustomInfFile");
		throw e;
	}
}

function GetTargetName(strName, strProjectName)
{
	try
	{
		var strTarget = strName;

		if (strName == 'main.c')
			strTarget =  wizard.FindSymbol('MAIN_FILE_NAME') + '.c';

		return strTarget; 
	}
	catch(e)
	{
		wizard.ReportError("Err source: GetTargetName");
	
		throw e;
	}
}

function AddFilesToCustomProj(proj, strProjectName, strProjectPath, InfFile)
{
	try
	{
		var projItems = proj.ProjectItems

		var strTemplatePath = wizard.FindSymbol('TEMPLATES_PATH');

		var strTpl = '';
		var strName = '';

		var strTextStream = InfFile.OpenAsTextStream(1, -2);
		while (!strTextStream.AtEndOfStream)
		{
			strTpl = strTextStream.ReadLine();
			if (strTpl != '')
			{
				strName = strTpl;
				var strTarget = GetTargetName(strName, strProjectName);
				var strTemplate = strTemplatePath + '\\' + strTpl;
				var strFile = strProjectPath + '\\' + strTarget;

				var bCopyOnly = false;  //"true" will only copy the file from strTemplate to strTarget without rendering/adding to the project
				var strExt = strName.substr(strName.lastIndexOf("."));
				if(strExt==".bmp" || strExt==".ico" || strExt==".gif" || strExt==".rtf" || strExt==".css")
					bCopyOnly = true;
				wizard.RenderTemplate(strTemplate, strFile, bCopyOnly);
				proj.Object.AddFile(strFile);
			}
		}
		strTextStream.Close();
	}
	catch(e)
	{
		wizard.ReportError("Err source: AddFilesToCustomProj");
		throw e;
	}
}
